@@ -3,12 +3,9 @@ from typing import Callable, Dict, List, Optional, Tuple, Union
 import numpy as np
 from faker.factory import Factory
 from faker.generator import Generator
+from genbase import LOCALE_MAP, CaseMixin, Readable, SeedMixin, get_locale
 from instancelib.instances.text import TextInstanceProvider
 from instancelib.labels.memory import MemoryLabelProvider
-from text_explainability.default import Readable
-
-from text_sensitivity.data.base import CaseMixin, SeedMixin
-from text_sensitivity.internationalization import LOCALE_MAP, get_locale
 
 
 class RandomEntity(Readable, SeedMixin, CaseMixin):
