@@ -3,9 +3,7 @@ from typing import Dict, List, Optional, Union
 
 import numpy as np
 import pandas as pd
-from text_explainability.default import Readable
-
-from text_sensitivity.data.base import CaseMixin, SeedMixin
+from genbase import CaseMixin, Readable, SeedMixin
 
 Label = Union[str, int]
 
